
## Welcome to Extended-maths
Extended-maths is an basic liberary which consist of simple maths functions and other most used utils functions.It consist of - factorial , palindrome , isSquare , temperature conversion and many more functions to come in upcoming versions.



## Installation
 

```python
pip install extended_maths
```

## Who should use Extnded-maths?
It is an open source library that anybody can use. 

- Anybondy who want to increase productivity.
- Professionals who prefer a low code solution.

## License
It is completely free and open-source and licensed under the [MIT](https://github.com/harsh204016/extended-maths/blob/main/LICENSE) license. 



